/*
 * Copyright 2017 by Kappich Systemberatung Aachen
 *
 * This file is part of de.kappich.pat.gnd.
 *
 * de.kappich.pat.gnd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.kappich.pat.gnd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.kappich.pat.gnd.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436
 * mail: <info@kappich.de>
 */

package de.kappich.pat.gnd.configBrowser;

import com.google.common.collect.Multimap;
import de.bsvrz.dav.daf.util.HashBagMap;
import de.bsvrz.sys.funclib.kappich.properties.DisplayUnit;
import de.bsvrz.sys.funclib.kappich.properties.ObjectProperties;
import de.bsvrz.sys.funclib.kappich.properties.PropertyFormatter;
import de.bsvrz.sys.funclib.kappich.properties.PropertyName;

import java.lang.reflect.Array;
import java.util.Collection;
import java.util.Map;

/**
 * Der <code>BrowserTreeFormatter</code> implementiert {@link PropertyFormatter} für die
 * Bedürfnisse des {@link BrowserTree BrowserTrees}.
 *
 * @author Kappich Systemberatung
 * @version $Revision$
 */
public class BrowserTreeFormatter implements PropertyFormatter{
	@Override
	public String format(final PropertyName propertyName, final Object o) {
		String s;
		if(o instanceof Iterable) {
			Iterable<?> iterable = (Iterable<?>) o;
			if(iterable instanceof Collection) {
				Collection<?> collection = (Collection<?>) iterable;
				int size = collection.size();
				if(size == 1) {
					s = ObjectProperties.objectToString(propertyName, collection.iterator().next());
				}
				else {
					s = size + " Elemente";
				}
			}
			else {
				int size = 0;
				for(final Object x : iterable) {
					size++;
					if(size == 11) break;
				}
				if(size == 11) {
					s = "über 10 Elemente";
				}
				else if(size == 1) {
					s = "ein Element";
				}
				else {
					s = size + " Elemente";
				}
			}
		}
		else if(o instanceof Map) {
			Map<?, ?> map = (Map<?, ?>) o;
			int size = map.size();
			if (size==1) {
				s = "1 Objekttyp";
			} else {
				s = size + " Objekttypen";
			}
		}
		else if(o instanceof Multimap) {
			Multimap<?, ?> map = (Multimap<?, ?>) o;
			int size = map.size();
			if (size==1) {
				s = "1 Objekttyp";
			} else {
				s = size + " Objekttypen";
			}
		}
		else if(o instanceof HashBagMap) {
			HashBagMap<?, ?> map = (HashBagMap<?, ?>) o;
			int size = map.keySet().size();
			if(size == 0) {
				s = "keine Mengen";
			}
			else if(size == 1) {
				s = "eine Menge";
			}
			else {
				s = size + " Mengen";
			}
		}
		else if(o.getClass().isArray()) {
			int size = Array.getLength(o);
			if(size == 1) {
				s = ObjectProperties.objectToString(propertyName, Array.get(o, 0));
			}
			else {
				s = size + " Elemente";
			}
		}
		else if(o instanceof Number && propertyName != null && !propertyName.unit().isEmpty()) {
			DisplayUnit displayUnit = new DisplayUnit(propertyName.unit(), propertyName.power(), propertyName.factor());
			s = displayUnit.format(((Number) o).doubleValue());
		}
		else {
			s = String.valueOf(o);
		}
		return s;
	}
}
